module Booby
  # Public: General error class.
  class Error < StandardError
  end

  # Public: Error raised when processor returns unexpected stuff.
  class InvalidResponseError < Error
    def initialize(obj)
      super(
        "Invalid response from processor. Expected `true', `false'" +
        "or an instance of processor, got: #{obj.inspect}"
      )
    end
  end

  # Public: Error raised when processor stumbles upon an unsupported option.
  class UnsupportedOptionError < Error
    def initialize(cmd, line_no)
      super("Unsupported option (line #{line_no}): #{cmd}")
    end
  end

  # Public: Error raised when arity check fails.
  class InvalidNumberOfParametersError < Error
    def initialize(expected, actual, cmd, line_no)
      expected = "minimum 1" if expected === true
      super(
        "Invalid number of parameters (line #{line_no}): "+
        "#{cmd} expects #{expected} parameter(s), got #{actual}"
      )
    end
  end
end
